==> fer_pytorch-0.5.0-py3-none-any.whl: fer_pytorch/train.py <==
from typing import Any, List, Tuple

import pytorch_lightning as pl
import torch
import torchmetrics
from torch.nn import functional as F

from fer_pytorch.config import CFG
from fer_pytorch.model import FERModel


class FERPLModel(pl.LightningModule):
    """
    The FER Pytorch Lightning class.

    Implemented for training and validation of the Facial Emotion Recognition model on FER+ dataset.
    """

    def __init__(self) -> None:
        super().__init__()
        self.accuracy = torchmetrics.Accuracy()
        self.f1_score = torchmetrics.F1Score(num_classes=CFG.target_size, average="weighted")
        self.model = FERModel(model_arch=CFG.model_name, pretrained=CFG.pretrained)

    def forward(self, x: torch.Tensor):  # type: ignore
        return self.model(x)

    def configure_optimizers(self) -> Tuple[List[Any], List[Any]]:
        optimizer = torch.optim.SGD(
            self.model.parameters(), lr=CFG.lr, momentum=CFG.momentum, weight_decay=CFG.weight_decay
        )
        lr_scheduler = torch.optim.lr_scheduler.CyclicLR(
            optimizer, base_lr=CFG.min_lr, max_lr=CFG.lr, mode="triangular2", step_size_up=1319
        )
        scheduler = {"scheduler": lr_scheduler, "interval": "step"}
        return [optimizer], [scheduler]

    def training_step(self, batch: Tuple[torch.Tensor, torch.Tensor], batch_idx: int):  # type: ignore
        images, labels = batch
        predictions = self.model(images)
        predicted_classes = predictions.argmax(dim=1)
        loss = F.cross_entropy(predictions, labels)
        acc = self.accuracy(predicted_classes, labels)
        self.log("train_loss", loss, prog_bar=True, on_step=False, on_epoch=True, logger=True)
        self.log("train_acc", acc, prog_bar=True, on_step=False, on_epoch=True, logger=True)
        return loss

    def validation_step(self, batch: Tuple[torch.Tensor, torch.Tensor], batch_idx: int):  # type: ignore
        images, labels = batch
        predictions = self.model(images)
        predicted_classes = predictions.argmax(dim=1)
        loss = F.cross_entropy(predictions, labels)
        acc = self.accuracy(predicted_classes, labels)
        f1 = self.f1_score(predicted_classes, labels)
        self.log("val_loss", loss, prog_bar=True, on_step=False, on_epoch=True, logger=True)
        self.log("val_acc", acc, prog_bar=True, on_step=False, on_epoch=True, logger=True)
        self.log("val_f1", f1, prog_bar=True, on_step=False, on_epoch=True, logger=True)
        return {"Accuracy": acc, "F1_score": f1}

    def test_step(self, batch: Tuple[torch.Tensor, torch.Tensor], batch_idx: int):  # type: ignore
        return self.validation_step(batch, batch_idx)

==> fer_pytorch-1.0.0-py3-none-any.whl: fer_pytorch/train.py <==
from typing import Any, List, Tuple

import pytorch_lightning as pl
import torch
import torchmetrics
from omegaconf import DictConfig
from torch.nn import functional as F

from fer_pytorch.model import FERModel
from fer_pytorch.utils.utils import load_obj


class FERPLModel(pl.LightningModule):
    """
    The FER Pytorch Lightning class.

    Implemented for training and validation of the Facial Emotion Recognition model on FER+ dataset.
    """

    def __init__(self, cfg: DictConfig) -> None:
        super().__init__()
        self.cfg = cfg
        self.accuracy = torchmetrics.Accuracy()
        self.f1_score = torchmetrics.F1Score(num_classes=self.cfg.dataset.target_size, average="weighted")

        self.model = FERModel(
            model_arch=self.cfg.model.model_name,
            pretrained=self.cfg.model.pretrained,
            num_classes=cfg.dataset.target_size,
        )

    def forward(self, x: torch.Tensor):  # type: ignore
        return self.model(x)

    def configure_optimizers(self) -> Tuple[List[Any], List[Any]]:
        optimizer = load_obj(self.cfg.optimizer.class_name)(self.model.parameters(), **self.cfg.optimizer.params)
        lr_scheduler = load_obj(self.cfg.scheduler.class_name)(optimizer, **self.cfg.scheduler.params)
        scheduler = {"scheduler": lr_scheduler, "interval": "step"}
        return [optimizer], [scheduler]

    def training_step(self, batch: Tuple[torch.Tensor, torch.Tensor], batch_idx: int):  # type: ignore
        images, labels = batch
        predictions = self.model(images)
        predicted_classes = predictions.argmax(dim=1)
        loss = F.cross_entropy(predictions, labels)
        acc = self.accuracy(predicted_classes, labels)
        self.log("train_loss", loss, prog_bar=True, on_step=False, on_epoch=True, logger=True)
        self.log("train_acc", acc, prog_bar=True, on_step=False, on_epoch=True, logger=True)
        return loss

    def validation_step(self, batch: Tuple[torch.Tensor, torch.Tensor], batch_idx: int):  # type: ignore
        images, labels = batch
        predictions = self.model(images)
        predicted_classes = predictions.argmax(dim=1)
        loss = F.cross_entropy(predictions, labels)
        acc = self.accuracy(predicted_classes, labels)
        f1 = self.f1_score(predicted_classes, labels)
        self.log("val_loss", loss, prog_bar=True, on_step=False, on_epoch=True, logger=True)
        self.log("val_acc", acc, prog_bar=True, on_step=False, on_epoch=True, logger=True)
        self.log("val_f1", f1, prog_bar=True, on_step=False, on_epoch=True, logger=True)
        return {"Accuracy": acc, "F1_score": f1}

    def test_step(self, batch: Tuple[torch.Tensor, torch.Tensor], batch_idx: int):  # type: ignore
        return self.validation_step(batch, batch_idx)
